@@ -10,6 +10,6 @@ utils::globalVariables(c("ni", "fi", "sumatorio", "variable2",
                          "suma.cuadrados.errores","suma.cuadrados.regresion","varianza.residual",
                          "varianza.residuos", "leverage", "puntos.palanca","error.norm",
                          "X","momento", "atipico", "lm", "mediamovil", "paso1_ive",
-                         "periodo", "pivot_wider", "variable_serie",
+                         "periodo", "pivot_wider", "matriz","variable_serie",
                          "A1","A2","c1","c2","c3","error_asimetria","var_coef","prediccion",".",
                          "variable1","variable2"))
