@@ -1,7 +1,7 @@
 .onAttach <- function(...) {
   packageStartupMessage("Este paquete est\u00e1 en desarrollo. Por favor, si detectas errores  o quieres hacernos alguna sugerencia, puedes ponerte en contacto con nosotros en:")
   packageStartupMessage("estadistic@uv.es")
-  packageStartupMessage("Tambien puedes serguirnos en el canal de youtube:")
+  packageStartupMessage("Tambi\u00e9n puedes seguirnos en el canal de youtube:")
   packageStartupMessage("https://go.uv.es/estadistic/youtube")
 }
 
